#!/bin/sh
# Copyright (c) 2000-2015 Synology Inc. All rights reserved.

PACKAGE_NAME="ThreatPrevention"
PACKAGE_TARGET_DIR="/var/packages/${PACKAGE_NAME}/target"
PACKAGE_USR_CONF_DIR="/var/packages/${PACKAGE_NAME}/etc"
SYNOTPSTOOL="${PACKAGE_TARGET_DIR}/tool/synotpstool"

# Variables that should be loaded by load_variable
HOOK_NAME=
CONF_ENABLE_SENSOR=
CONF_INTERFACE_LIST=
NET_TOPOLOGY=

synotps_log()
{
	logger -s -p info -t synotps $1
}

load_variable()
{
	HOOK_NAME=`basename $0`
	CONF_ENABLE_SENSOR=`/bin/get_key_value ${PACKAGE_USR_CONF_DIR}/sensor.conf enable_sensor`
	CONF_INTERFACE_LIST=`/bin/get_key_value ${PACKAGE_USR_CONF_DIR}/sensor.conf interface_list`
	NET_TOPOLOGY=`/bin/get_key_value /etc/synoinfo.conf net_topology`
}

log_variable()
{
	synotps_log "====> ${HOOK_NAME}"
	synotps_log "IFNAME=${IFNAME}"
	synotps_log "IS_LINK=${IS_LINK}"
	synotps_log "NEW_ADDRESS=${NEW_ADDRESS}"
	synotps_log "CONF_ENABLE_SENSOR=${CONF_ENABLE_SENSOR}"
	synotps_log "CONF_INTERFACE_LIST=${CONF_INTERFACE_LIST}"
	synotps_log "NET_TOPOLOGY=${NET_TOPOLOGY}"
}

reset_iptables_sensor()
{
	synotps_log "reset iptables synotps ${IFNAME}"
	${SYNOTPSTOOL} --sensor-reload -i ${IFNAME}
}

restart_sensor()
{
	synotps_log "restart synotps ${IFNAME}"
	${SYNOTPSTOOL} --sensor-daemon -d #disable
	${SYNOTPSTOOL} --sensor-daemon -e #enable
}

hook_handler()
{
	load_variable

	log_variable

	if [ "x${NET_TOPOLOGY}" == "xrouter" ]; then
		synotps_log "wait for interface ready"
		sleep 5

		case $1 in
			reset_iptables)
				reset_iptables_sensor
				;;
			restart_sensor)
				restart_sensor
				;;
			*)
				synotps_log "unknown option ($1)"
		esac
	fi
}

